pub struct EdwardsPoint { /* private fields */ }Implementations
Sourceimpl EdwardsPoint
impl EdwardsPoint
pub fn get_u(&self) -> &AllocatedNum<Scalar>
pub fn get_v(&self) -> &AllocatedNum<Scalar>
pub fn assert_not_small_order<CS>(&self, cs: CS) -> Result<(), SynthesisError>where
CS: ConstraintSystem<Scalar>,
pub fn inputize<CS>(&self, cs: CS) -> Result<(), SynthesisError>where
CS: ConstraintSystem<Scalar>,
Sourcepub fn repr<CS>(&self, cs: CS) -> Result<Vec<Boolean>, SynthesisError>where
CS: ConstraintSystem<Scalar>,
pub fn repr<CS>(&self, cs: CS) -> Result<Vec<Boolean>, SynthesisError>where
CS: ConstraintSystem<Scalar>,
This converts the point into a representation.
Sourcepub fn witness<CS>(
cs: CS,
p: Option<ExtendedPoint>,
) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<Scalar>,
pub fn witness<CS>(
cs: CS,
p: Option<ExtendedPoint>,
) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<Scalar>,
This ‘witnesses’ a point inside the constraint system. It guarantees the point is on the curve.
Sourcepub fn conditionally_select<CS>(
&self,
cs: CS,
condition: &Boolean,
) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<Scalar>,
pub fn conditionally_select<CS>(
&self,
cs: CS,
condition: &Boolean,
) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<Scalar>,
Returns self if condition is true, and the neutral
element (0, 1) otherwise.
Sourcepub fn mul<CS>(&self, cs: CS, by: &[Boolean]) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<Scalar>,
pub fn mul<CS>(&self, cs: CS, by: &[Boolean]) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<Scalar>,
Performs a scalar multiplication of this twisted Edwards point by a scalar represented as a sequence of booleans in little-endian bit order.
pub fn interpret<CS>(
cs: CS,
u: &AllocatedNum<Scalar>,
v: &AllocatedNum<Scalar>,
) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<Scalar>,
pub fn double<CS>(&self, cs: CS) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<Scalar>,
Sourcepub fn add<CS>(&self, cs: CS, other: &Self) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<Scalar>,
pub fn add<CS>(&self, cs: CS, other: &Self) -> Result<Self, SynthesisError>where
CS: ConstraintSystem<Scalar>,
Perform addition between any two points