Module sapling

Module sapling 

Helpers for creating MASP Sapling proofs.

Structs

BatchValidator
Batch validation context for MASP/Sapling.
SaplingProvingContext
A context object for creating the Sapling components of a Zcash transaction.
SaplingVerificationContext
A context object for verifying the Sapling components of a single Zcash transaction.
SaplingVerificationContextInner
A context object for verifying the Sapling components of a Zcash transaction.