Helpers for creating MASP Sapling proofs.
Structs
- Batch
Validator - Batch validation context for MASP/Sapling.
- Sapling
Proving Context - A context object for creating the Sapling components of a Zcash transaction.
- Sapling
Verification Context - A context object for verifying the Sapling components of a single Zcash transaction.
- Sapling
Verification Context Inner - A context object for verifying the Sapling components of a Zcash transaction.